<?php

/**
 * hostby functions and definitions
  @package Hostby
 *
*/

/* Set the content width in pixels, based on the theme's design and stylesheet.
*/
if( ! function_exists( 'hostby_theme_setup' ) ) {

	function hostby_theme_setup() {

		$GLOBALS['content_width'] = apply_filters( 'hostby_content_width', 980 );

		load_theme_textdomain( 'hostby', get_template_directory() . '/languages' );

        // Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

        // Add title tag 
		add_theme_support( 'title-tag' );

		// Add default logo support		
        add_theme_support( 'custom-logo');

        add_theme_support('post-thumbnails');
        add_image_size('hostby-services-thumbnail',60,60,true);
        add_image_size('hostby-page-thumbnail',738,423, true);
        add_image_size('hostby-about-thumbnail',370,225, true);
        add_image_size('hostby-blog-front-thumbnail',370,225, true);
        add_image_size('hostby-projects-thumbnail',500,400, true);
        
        // Add theme support for Semantic Markup
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption'
		) ); 

		$defaults = array(
			'default-image'          => get_template_directory_uri() .'/assets/images/blog-banner.jpg',
			'width'                  => 1920,
			'height'                 => 540,
			'uploads'                => true,
			'default-text-color'     => "#000",
			'wp-head-callback'       => 'hostby_header_style',
			
			);
		add_theme_support( 'custom-header', $defaults );

		// Menus
		register_nav_menus(
			array(
                'primary' => esc_html__('Primary Menu', 'hostby'),
            )
		);
		// add excerpt support for pages
        add_post_type_support( 'page', 'excerpt' );

        if ( is_singular() && comments_open() ) {
			wp_enqueue_script( 'comment-reply' );
        }
		// Add theme support for selective refresh for widgets.
        add_theme_support( 'customize-selective-refresh-widgets' );
		
    	// To use additional css
 	    add_editor_style( 'assets/css/editor-style.css' );
		
		// Custom Backgrounds
   		add_theme_support( 'custom-background', array(
  			'default-color' => 'ffffff',
    	) );

	}
	add_action( 'after_setup_theme', 'hostby_theme_setup' );
}

// Register Nav Walker class_alias
   require_once('class-wp-bootstrap-navwalker.php');
/**
 * Enqueue CSS stylesheets
 */		
if( ! function_exists( 'hostby_enqueue_styles' ) ) {
	function hostby_enqueue_styles() {	
	    
	    wp_enqueue_style('hostby-font', 'https://fonts.googleapis.com/css?family=Nunito:300,400,600,700,800');
		wp_enqueue_style('bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.css');
		wp_enqueue_style('font-awesome', get_template_directory_uri() .'/assets/css/font-awesome.css');
		wp_enqueue_style('carousel', get_template_directory_uri() .'/assets/css/owl.carousel.css');
		wp_enqueue_style('hostby-theme', get_template_directory_uri() .'/assets/css/owl.theme.default.css');
		wp_enqueue_style('animate', get_template_directory_uri() .'/assets/css/animate.css');
		wp_enqueue_style('menubar', get_template_directory_uri() . '/assets/css/menubar.css');	
		// main style
		wp_enqueue_style( 'hostby-style', get_stylesheet_uri() );
		wp_enqueue_style('hostby-blue', get_template_directory_uri() . '/assets/css/skin-blue.css');
		 
		wp_enqueue_style('responsive', get_template_directory_uri() .'/assets/css/responsive.css');
	}
	add_action( 'wp_enqueue_scripts', 'hostby_enqueue_styles');
}
/**
 * Enqueue JS scripts
*/

if( ! function_exists( 'hostby_enqueue_scripts' ) ) {
	function hostby_enqueue_scripts() {   
		wp_enqueue_script('jquery');
		wp_enqueue_script('popper', get_template_directory_uri() . '/assets/js/popper.js',array(),'', true);
		wp_enqueue_script('bootstrap', get_template_directory_uri() . '/assets/js/bootstrap.js',array(),'', true);
		wp_enqueue_script('carousel', get_template_directory_uri() . '/assets/js/owl.carousel.js',array(),'', true);
		wp_enqueue_script('imagesloaded', get_template_directory_uri() . '/assets/js/imagesloaded.js',array(),'', true);
		wp_enqueue_script('isotope', get_template_directory_uri() . '/assets/js/isotope.js',array(),'', true);
		wp_enqueue_script('poptrox', get_template_directory_uri() . '/assets/js/jquery.poptrox.js',array(),'', true);
		wp_enqueue_script('hostby-custom', get_template_directory_uri() . '/assets/js/custom.js',array(),'', true);
	}
	add_action( 'wp_enqueue_scripts', 'hostby_enqueue_scripts' );
}

/**
 * Register sidebars for hostby
*/
function hostby_sidebars() {

	// Blog Sidebar
	
	register_sidebar(array(
		'name' => esc_html__( 'Blog Sidebar', "hostby"),
		'id' => 'blog-sidebar',
		'description' => esc_html__( 'Sidebar on the blog layout.', "hostby"),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="border-arrow">',
		'after_title' => '</h3>',
	));
  	

	// Footer Sidebar
	register_sidebar(array(
		'name' => esc_html__( 'Footer Widget Area 1', "hostby"),
		'id' => 'hostby-footer-widget-area-1',
		'description' => esc_html__( 'The footer widget area 1', "hostby"),
		'before_widget' => '<div class="widget %2$s"> ',
		'after_widget' => '</div> ',
		'before_title' => '<h4 class="foot-heading">',
		'after_title' => '</h4>',
	));	
	
	register_sidebar(array(
		'name' => esc_html__( 'Footer Widget Area 2', "hostby"),
		'id' => 'hostby-footer-widget-area-2',
		'description' => esc_html__( 'The footer widget area 2', "hostby"),
		'before_widget' => '<div class="widget %2$s">  ',
		'after_widget' => ' </div>',
		'before_title' => '<h4 class="foot-heading">',
		'after_title' => '</h4>',
	));	
	
	register_sidebar(array(
		'name' => esc_html__( 'Footer Widget Area 3', "hostby"),
		'id' => 'hostby-footer-widget-area-3',
		'description' => esc_html__( 'The footer widget area 3', "hostby"),
		'before_widget' => '<div class="widget %2$s"> ',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="foot-heading">',
		'after_title' => '</h4>',
	));	
	
	register_sidebar(array(
		'name' => esc_html__( 'Footer Widget Area 4', "hostby"),
		'id' => 'hostby-footer-widget-area-4',
		'description' => esc_html__( 'The footer widget area 4', "hostby"),
		'before_widget' => '<div class="widget %2$s"> ',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="foot-heading">',
		'after_title' => '</h4>',
	));		
}

add_action( 'widgets_init', 'hostby_sidebars' );

function hostby_header_style()
{
	$header_text_color = get_header_textcolor();
	?>
		<style type="text/css">
			<?php
				//Check if user has defined any header image.
				if ( get_header_image() ) :
			?>
				.site-title{
					color: #<?php echo esc_attr($header_text_color); ?>;
					
				}
			<?php endif; ?>	
		</style>
	<?php

}

 /**
 * Comment layout
 */
function hostby_comments( $comment, $args, $depth ) { 
    $GLOBALS['comment'] = $comment; ?>
	<div <?php comment_class('comments'); ?> id="<?php comment_ID() ?>">
	    <?php if ($comment->comment_approved == '0') : ?>
	        <div class="alert alert-info">
	          <p><?php esc_html_e( 'Your comment is awaiting under moderation.', 'hostby' ) ?></p>
	        </div>
	    <?php endif; ?>
	    <div class="comment-inner">
            <a class="reply"><?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?></a>
	        <div class="com-img">
	           <a href="#"><?php echo get_avatar( $comment,'88', null,'User', array( 'class' => array( 'media-object','' ) )); ?></a>
	        </div>
	        <div class="com-content">
	            <h4>
	                <?php 
	                        /* translators: '%1$s %2$s: edit term */
	                printf(esc_html__( '%1$s %2$s', 'hostby' ), get_comment_author_link(), edit_comment_link(esc_html__( '(Edit)', 'hostby' ),'  ','') ) ?> </h4>
	                <h5 class="fw-600"><time datetime="<?php echo comment_time('c'); ?>">
						<?php printf(  /* translators: 1: date, 2: time */
							_x( '%1$s at %2$s', '1: date, 2: time', 'hostby' ),
								get_comment_date(),
								get_comment_time()
							); ?></time>
					</h5>
	            <?php comment_text() ;?>
	        </div>
        </div>
	</div>
<?php
} 


/**
 * Customizer Settings
*/
require get_template_directory(). '/customizer.php';

if ( ! function_exists( 'hostby_customize_search_form' ) ) :
	function hostby_customize_search_form() {
        
        $form = '<div class="widget search-widget"><form role="search" method="get" class=" input-group" action="' . esc_url( home_url( '/' ) ) . '">
			
			<span class="screen-reader-text">' . esc_html( '', 'label', 'hostby' ) . '</span>
			<input type="search" class="form-group form-control" placeholder="' . esc_attr_x( 'Search', 'placeholder', 'hostby' ) . '" value="' . get_search_query() . '" name="s" title="' . esc_attr_x( 'Search for:', 'label', 'hostby' ) . '" />
			
			<button type="submit" class="btn btn-widget">
                <i class="fa fa-search"></i>
            </button>
            </form></div>';
        return $form;
    }
endif;
add_filter( 'get_search_form', 'hostby_customize_search_form', 15 );

?>

